==> camel-k-model-v1alpha1-6.5.1-sources.jar: io/fabric8/camelk/v1alpha1/KameletBindingSpecFluent.java <==
package io.fabric8.camelk.v1alpha1;

import io.fabric8.camelk.v1.IntegrationSpec;
import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.util.function.Predicate;
import java.lang.Integer;
import java.lang.Deprecated;
import java.util.Iterator;
import java.util.Collection;
import java.util.List;
import java.lang.Boolean;

 /**
  * Generated
  */
public interface KameletBindingSpecFluent<A extends KameletBindingSpecFluent<A>> extends Fluent<A>{
  
  /**
   * This method has been deprecated, please use method buildErrorHandler instead.
   * @return The buildable object.
   */
  @Deprecated
  public ErrorHandlerSpec getErrorHandler();
  public ErrorHandlerSpec buildErrorHandler();
  public A withErrorHandler(ErrorHandlerSpec errorHandler);
  public Boolean hasErrorHandler();
  public KameletBindingSpecFluent.ErrorHandlerNested<A> withNewErrorHandler();
  public KameletBindingSpecFluent.ErrorHandlerNested<A> withNewErrorHandlerLike(ErrorHandlerSpec item);
  public KameletBindingSpecFluent.ErrorHandlerNested<A> editErrorHandler();
  public KameletBindingSpecFluent.ErrorHandlerNested<A> editOrNewErrorHandler();
  public KameletBindingSpecFluent.ErrorHandlerNested<A> editOrNewErrorHandlerLike(ErrorHandlerSpec item);
  public IntegrationSpec getIntegration();
  public A withIntegration(IntegrationSpec integration);
  public Boolean hasIntegration();
  public Integer getReplicas();
  public A withReplicas(Integer replicas);
  public Boolean hasReplicas();
  
  /**
   * This method has been deprecated, please use method buildSink instead.
   * @return The buildable object.
   */
  @Deprecated
  public Endpoint getSink();
  public Endpoint buildSink();
  public A withSink(Endpoint sink);
  public Boolean hasSink();
  public KameletBindingSpecFluent.SinkNested<A> withNewSink();
  public KameletBindingSpecFluent.SinkNested<A> withNewSinkLike(Endpoint item);
  public KameletBindingSpecFluent.SinkNested<A> editSink();
  public KameletBindingSpecFluent.SinkNested<A> editOrNewSink();
  public KameletBindingSpecFluent.SinkNested<A> editOrNewSinkLike(Endpoint item);
  
  /**
   * This method has been deprecated, please use method buildSource instead.
   * @return The buildable object.
   */
  @Deprecated
  public Endpoint getSource();
  public Endpoint buildSource();
  public A withSource(Endpoint source);
  public Boolean hasSource();
  public KameletBindingSpecFluent.SourceNested<A> withNewSource();
  public KameletBindingSpecFluent.SourceNested<A> withNewSourceLike(Endpoint item);
  public KameletBindingSpecFluent.SourceNested<A> editSource();
  public KameletBindingSpecFluent.SourceNested<A> editOrNewSource();
  public KameletBindingSpecFluent.SourceNested<A> editOrNewSourceLike(Endpoint item);
  public A addToSteps(Integer index,Endpoint item);
  public A setToSteps(Integer index,Endpoint item);
  public A addToSteps(io.fabric8.camelk.v1alpha1.Endpoint... items);
  public A addAllToSteps(Collection<Endpoint> items);
  public A removeFromSteps(io.fabric8.camelk.v1alpha1.Endpoint... items);
  public A removeAllFromSteps(Collection<Endpoint> items);
  public A removeMatchingFromSteps(Predicate<EndpointBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildSteps instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<Endpoint> getSteps();
  public List<Endpoint> buildSteps();
  public Endpoint buildStep(Integer index);
  public Endpoint buildFirstStep();
  public Endpoint buildLastStep();
  public Endpoint buildMatchingStep(Predicate<EndpointBuilder> predicate);
  public Boolean hasMatchingStep(Predicate<EndpointBuilder> predicate);
  public A withSteps(List<Endpoint> steps);
  public A withSteps(io.fabric8.camelk.v1alpha1.Endpoint... steps);
  public Boolean hasSteps();
  public KameletBindingSpecFluent.StepsNested<A> addNewStep();
  public KameletBindingSpecFluent.StepsNested<A> addNewStepLike(Endpoint item);
  public KameletBindingSpecFluent.StepsNested<A> setNewStepLike(Integer index,Endpoint item);
  public KameletBindingSpecFluent.StepsNested<A> editStep(Integer index);
  public KameletBindingSpecFluent.StepsNested<A> editFirstStep();
  public KameletBindingSpecFluent.StepsNested<A> editLastStep();
  public KameletBindingSpecFluent.StepsNested<A> editMatchingStep(Predicate<EndpointBuilder> predicate);
  public interface ErrorHandlerNested<N> extends Nested<N>,ErrorHandlerSpecFluent<KameletBindingSpecFluent.ErrorHandlerNested<N>>{
    public N and();
    public N endErrorHandler();
    
  }
  public interface SinkNested<N> extends Nested<N>,EndpointFluent<KameletBindingSpecFluent.SinkNested<N>>{
    public N and();
    public N endSink();
    
  }
  public interface SourceNested<N> extends Nested<N>,EndpointFluent<KameletBindingSpecFluent.SourceNested<N>>{
    public N and();
    public N endSource();
    
  }
  public interface StepsNested<N> extends Nested<N>,EndpointFluent<KameletBindingSpecFluent.StepsNested<N>>{
    public N and();
    public N endStep();
    
  }
  
}

==> camel-k-model-v1alpha1-6.7.1-sources.jar: io/fabric8/camelk/v1alpha1/KameletBindingSpecFluent.java <==
package io.fabric8.camelk.v1alpha1;

import io.fabric8.camelk.v1.IntegrationSpec;
import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import com.fasterxml.jackson.annotation.JsonInclude;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.util.function.Predicate;
import java.lang.Integer;
import java.lang.Deprecated;
import java.util.Iterator;
import java.util.Collection;
import java.util.List;
import java.lang.Boolean;

 /**
  * Generated
  */
public interface KameletBindingSpecFluent<A extends KameletBindingSpecFluent<A>> extends Fluent<A>{
  
  /**
   * This method has been deprecated, please use method buildErrorHandler instead.
   * @return The buildable object.
   */
  @Deprecated
  public ErrorHandlerSpec getErrorHandler();
  public ErrorHandlerSpec buildErrorHandler();
  public A withErrorHandler(ErrorHandlerSpec errorHandler);
  public Boolean hasErrorHandler();
  public KameletBindingSpecFluent.ErrorHandlerNested<A> withNewErrorHandler();
  public KameletBindingSpecFluent.ErrorHandlerNested<A> withNewErrorHandlerLike(ErrorHandlerSpec item);
  public KameletBindingSpecFluent.ErrorHandlerNested<A> editErrorHandler();
  public KameletBindingSpecFluent.ErrorHandlerNested<A> editOrNewErrorHandler();
  public KameletBindingSpecFluent.ErrorHandlerNested<A> editOrNewErrorHandlerLike(ErrorHandlerSpec item);
  public IntegrationSpec getIntegration();
  public A withIntegration(IntegrationSpec integration);
  public Boolean hasIntegration();
  public Integer getReplicas();
  public A withReplicas(Integer replicas);
  public Boolean hasReplicas();
  
  /**
   * This method has been deprecated, please use method buildSink instead.
   * @return The buildable object.
   */
  @Deprecated
  public Endpoint getSink();
  public Endpoint buildSink();
  public A withSink(Endpoint sink);
  public Boolean hasSink();
  public KameletBindingSpecFluent.SinkNested<A> withNewSink();
  public KameletBindingSpecFluent.SinkNested<A> withNewSinkLike(Endpoint item);
  public KameletBindingSpecFluent.SinkNested<A> editSink();
  public KameletBindingSpecFluent.SinkNested<A> editOrNewSink();
  public KameletBindingSpecFluent.SinkNested<A> editOrNewSinkLike(Endpoint item);
  
  /**
   * This method has been deprecated, please use method buildSource instead.
   * @return The buildable object.
   */
  @Deprecated
  public Endpoint getSource();
  public Endpoint buildSource();
  public A withSource(Endpoint source);
  public Boolean hasSource();
  public KameletBindingSpecFluent.SourceNested<A> withNewSource();
  public KameletBindingSpecFluent.SourceNested<A> withNewSourceLike(Endpoint item);
  public KameletBindingSpecFluent.SourceNested<A> editSource();
  public KameletBindingSpecFluent.SourceNested<A> editOrNewSource();
  public KameletBindingSpecFluent.SourceNested<A> editOrNewSourceLike(Endpoint item);
  public A addToSteps(int index,Endpoint item);
  public A setToSteps(int index,Endpoint item);
  public A addToSteps(io.fabric8.camelk.v1alpha1.Endpoint... items);
  public A addAllToSteps(Collection<Endpoint> items);
  public A removeFromSteps(io.fabric8.camelk.v1alpha1.Endpoint... items);
  public A removeAllFromSteps(Collection<Endpoint> items);
  public A removeMatchingFromSteps(Predicate<EndpointBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildSteps instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<Endpoint> getSteps();
  public List<Endpoint> buildSteps();
  public Endpoint buildStep(int index);
  public Endpoint buildFirstStep();
  public Endpoint buildLastStep();
  public Endpoint buildMatchingStep(Predicate<EndpointBuilder> predicate);
  public Boolean hasMatchingStep(Predicate<EndpointBuilder> predicate);
  public A withSteps(List<Endpoint> steps);
  public A withSteps(io.fabric8.camelk.v1alpha1.Endpoint... steps);
  public Boolean hasSteps();
  public KameletBindingSpecFluent.StepsNested<A> addNewStep();
  public KameletBindingSpecFluent.StepsNested<A> addNewStepLike(Endpoint item);
  public KameletBindingSpecFluent.StepsNested<A> setNewStepLike(int index,Endpoint item);
  public KameletBindingSpecFluent.StepsNested<A> editStep(int index);
  public KameletBindingSpecFluent.StepsNested<A> editFirstStep();
  public KameletBindingSpecFluent.StepsNested<A> editLastStep();
  public KameletBindingSpecFluent.StepsNested<A> editMatchingStep(Predicate<EndpointBuilder> predicate);
  public interface ErrorHandlerNested<N> extends Nested<N>,ErrorHandlerSpecFluent<KameletBindingSpecFluent.ErrorHandlerNested<N>>{
    public N and();
    public N endErrorHandler();
    
  }
  public interface SinkNested<N> extends Nested<N>,EndpointFluent<KameletBindingSpecFluent.SinkNested<N>>{
    public N and();
    public N endSink();
    
  }
  public interface SourceNested<N> extends Nested<N>,EndpointFluent<KameletBindingSpecFluent.SourceNested<N>>{
    public N and();
    public N endSource();
    
  }
  public interface StepsNested<N> extends Nested<N>,EndpointFluent<KameletBindingSpecFluent.StepsNested<N>>{
    public N and();
    public N endStep();
    
  }
  
}
